@@ -6,7 +6,13 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. 
  */
  
- "use strict";
+"use strict";
+
+var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+
+XPCOMUtils.defineLazyModuleGetters(this, {
+    CalRecurrenceInfo: "resource:///modules/CalRecurrenceInfo.jsm",
+}); 
 
 // - https://dxr.mozilla.org/comm-central/source/calendar/base/public/calIEvent.idl
 // - https://dxr.mozilla.org/comm-central/source/calendar/base/public/calIItemBase.idl
@@ -258,7 +264,7 @@ var sync = {
 
 
     singleFolder: async function (syncData)  {
-        // add target to syncData (getTarget() will throw "nolightning" if lightning missing)
+        // add target to syncData
         try {
             // accessing the target for the first time will check if it is avail and if not will create it (if possible)
             syncData.target = await syncData.currentFolderData.targetData.getTarget();
@@ -354,11 +360,30 @@ var sync = {
             await eas.sync.revertLocalChanges(syncData);
         }
 
-        await eas.network.getItemEstimate (syncData);
-        await eas.sync.requestRemoteChanges (syncData); 
+        await eas.network.getItemEstimate(syncData);
+        await eas.sync.requestRemoteChanges(syncData); 
 
         if (!syncData.currentFolderData.getFolderProperty("downloadonly")) {		
-            await eas.sync.sendLocalChanges(syncData);
+            let sendChanges = await eas.sync.sendLocalChanges(syncData);
+            if (sendChanges) {
+                // This is ugly as hell, but Microsoft sometimes sets the state of the
+                // remote account to "changed" after we have send a local change (even
+                // though it has acked the change) and this will cause the server to
+                // send a change request with our next sync. Because we follow the
+                // "server wins" policy, this will overwrite any additional local change
+                // we have done in the meantime. This is stupid, but we wait 2s and
+                // hope it is enough to catch this second ack of the local change.
+                let timer =  Components.classes["@mozilla.org/timer;1"].createInstance(Components.interfaces.nsITimer);
+                await new Promise(function(resolve, reject) {
+                    let event = {
+                        notify: function(timer) {
+                            resolve();
+                        }
+                    }
+                    timer.initWithCallback(event, 2000, Components.interfaces.nsITimer.TYPE_ONE_SHOT);
+                });
+                await eas.sync.requestRemoteChanges(syncData);
+            }
         }
     },
     
@@ -441,6 +466,7 @@ var sync = {
         
         let done = false;
         let numberOfItemsToSend = maxnumbertosend;
+        let sendChanges = false;
         do {
             syncData.setSyncState("prepare.request.localchanges");
             syncData.request = "";
@@ -448,6 +474,7 @@ var sync = {
 
             //get changed items from ChangeLog
             let changes = syncData.target.getItemsFromChangeLog(numberOfItemsToSend);
+            //console.log("chnages", changes);
             let c=0;
             let e=0;
 
@@ -532,7 +559,7 @@ wbxml.otag("Exceptions");
     wbxml.ctag();
 wbxml.ctag();*/
 
-                                                        wbxml.append(eas.sync.getWbxmlFromThunderbirdItem(item, syncData));
+                                                        wbxml.append(await eas.sync.getWbxmlFromThunderbirdItem(item, syncData));
                                                         wbxml.switchpage("AirSync");
                                                     wbxml.ctag();
                                                 wbxml.ctag();
@@ -555,7 +582,7 @@ wbxml.ctag();*/
                                                 wbxml.atag("ServerId", changes[i].itemId);
                                                     wbxml.otag("ApplicationData");
                                                         wbxml.switchpage(syncData.type);
-                                                        wbxml.append(eas.sync.getWbxmlFromThunderbirdItem(item, syncData));
+                                                        wbxml.append(await eas.sync.getWbxmlFromThunderbirdItem(item, syncData));
                                                         wbxml.switchpage("AirSync");
                                                     wbxml.ctag();
                                                 wbxml.ctag();
@@ -589,7 +616,7 @@ wbxml.ctag();*/
 
 
             if (c > 0) { //if there was at least one actual local change, send request
-
+                sendChanges = true;
                 //SEND REQUEST & VALIDATE RESPONSE
                 syncData.setSyncState("send.request.localchanges");
                 let response = await eas.network.sendRequest(wbxml.getBytes(), "Sync", syncData);
@@ -671,7 +698,7 @@ wbxml.ctag();*/
         if (syncData.failedItems.length > 0) {
             throw eas.sync.finish("warning", "ServerRejectedSomeItems::" + syncData.failedItems.length);                            
         }
-        
+        return sendChanges;
     },
 
 
@@ -1110,9 +1137,9 @@ wbxml.ctag();*/
         }
     },
     
-    getWbxmlFromThunderbirdItem(item, syncData, isException = false) {
+    async getWbxmlFromThunderbirdItem(item, syncData, isException = false) {
         try {
-            let wbxml = eas.sync[syncData.type].getWbxmlFromThunderbirdItem(item, syncData, isException);
+            let wbxml = await eas.sync[syncData.type].getWbxmlFromThunderbirdItem(item, syncData, isException);
             return wbxml;
         } catch (e) {
             TbSync.eventlog.add("warning", syncData.eventLogInfo, "BadItemSkipped::JavaScriptError", item.toString());
@@ -1149,7 +1176,7 @@ wbxml.ctag();*/
             let cats = [];
             if (Array.isArray(data.Categories.Category)) cats = data.Categories.Category;
             else cats.push(data.Categories.Category);
-            item.setCategories(cats.length, cats);
+            item.setCategories(cats);
         }
     },
     
@@ -1205,7 +1232,7 @@ wbxml.ctag();*/
     //item is a native lightning item
     setItemRecurrence: function (item, syncData, data, timezone) {
         if (data.Recurrence) {
-            item.recurrenceInfo = TbSync.lightning.cal.createRecurrenceInfo();
+            item.recurrenceInfo = new CalRecurrenceInfo();
             item.recurrenceInfo.item = item;
             let recRule = TbSync.lightning.cal.createRecurrenceRule();
             switch (data.Recurrence.Type) {
@@ -1229,12 +1256,12 @@ wbxml.ctag();*/
                 // TODO
             }
             if (data.Recurrence.DayOfMonth) {
-                recRule.setComponent("BYMONTHDAY", 1, [data.Recurrence.DayOfMonth]);
+                recRule.setComponent("BYMONTHDAY", [data.Recurrence.DayOfMonth]);
             }
             if (data.Recurrence.DayOfWeek) {
                 let DOW = data.Recurrence.DayOfWeek;
                 if (DOW == 127 && (recRule.type == "MONTHLY" || recRule.type == "YEARLY")) {
-                    recRule.setComponent("BYMONTHDAY", 1, [-1]);
+                    recRule.setComponent("BYMONTHDAY", [-1]);
                 }
                 else {
                     let days = [];
@@ -1251,11 +1278,11 @@ wbxml.ctag();*/
                             }
                         }
                     }
-                    recRule.setComponent("BYDAY", days.length, days);
+                    recRule.setComponent("BYDAY", days);
                 }
             }
             if (data.Recurrence.FirstDayOfWeek) {
-                //recRule.setComponent("WKST", 1, [data.Recurrence.FirstDayOfWeek]); // WKST is not a valid component
+                //recRule.setComponent("WKST", [data.Recurrence.FirstDayOfWeek]); // WKST is not a valid component
                 //recRule.weekStart = data.Recurrence.FirstDayOfWeek; // - (NS_ERROR_NOT_IMPLEMENTED) [calIRecurrenceRule.weekStart]
                 TbSync.eventlog.add("info", syncData.eventLogInfo, "FirstDayOfWeek tag ignored (not supported).", item.icalString);                
             }
@@ -1267,7 +1294,7 @@ wbxml.ctag();*/
                 // TODO
             }
             if (data.Recurrence.MonthOfYear) {
-                recRule.setComponent("BYMONTH", 1, [data.Recurrence.MonthOfYear]);
+                recRule.setComponent("BYMONTH", [data.Recurrence.MonthOfYear]);
             }
             if (data.Recurrence.Occurrences) {
                 recRule.count = data.Recurrence.Occurrences;
@@ -1315,7 +1342,7 @@ wbxml.ctag();*/
         }
     },
 
-    getItemRecurrence: function (item, syncData, localStartDate = null) {
+    getItemRecurrence: async function (item, syncData, localStartDate = null) {
         let asversion = syncData.accountData.getAccountProperty("asversion");
         let wbxml = eas.wbxmltools.createWBXML("", syncData.type); //init wbxml with "" and not with precodes, also activate type codePage (Calendar, Tasks etc)
 
@@ -1463,7 +1490,7 @@ wbxml.ctag();*/
                         let replacement = item.recurrenceInfo.getExceptionFor(exceptionId);
                         wbxml.otag("Exception");
                             wbxml.atag("ExceptionStartTime", eas.tools.getIsoUtcString(exceptionId));
-                            wbxml.append(eas.sync.getWbxmlFromThunderbirdItem(replacement, syncData, true));
+                            wbxml.append(await eas.sync.getWbxmlFromThunderbirdItem(replacement, syncData, true));
                         wbxml.ctag();
                     }
                     wbxml.ctag();
